<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Borang Penerima");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Borang Penerima");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "borang Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Anda boleh menetapkan lebih daripada satu penerima dengan mengasingkan e-mel dengan koma.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Menyimpan penerima ...");
define('VIEW_FORM_TABLES_HEADING', "Lihat Borang Jadual");
define('VIEW_FORM_TABLES_BTN', "Lihat Borang Jadual");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Pilih jadual untuk Lihat");
define('VIEW_FORM_TABLES_FILTER_READ', "Penapis Baca Mesej");
?>